@@ -7,7 +7,7 @@ from flatland.flatland_exceptions import CellOccupiedFE, SheetWidthExceededFE, S
 from flatland.connector_subsystem.connector_layout_specification import ConnectorLayoutSpecification as connector_layout
 from flatland.node_subsystem.diagram_layout_specification import DiagramLayoutSpecification as diagram_layout
 from flatland.geometry_domain.linear_geometry import expand_boundaries, span, step_edge_distance
-from flatland.datatypes.geometry_types import Position
+from flatland.datatypes.geometry_types import Position, Rect_Size
 from flatland.node_subsystem.spanning_node import SpanningNode
 from flatland.node_subsystem.single_cell_node import SingleCellNode
 from flatland.datatypes.connection_types import Orientation
@@ -98,27 +98,38 @@ class Grid:
         Draw Grid on Tablet for diagnostic purposes
         """
 
-        layer = self.Diagram.Layer
+        grid_layer = self.Diagram.Canvas.Tablet.layers['grid']
 
         if show_grid:
             self.logger.info("Drawing grid")
             # Draw rows
             left_extent = self.Diagram.Origin.x
             right_extent = self.Diagram.Origin.x + self.Diagram.Size.width
-            for h in self.Row_boundaries:
-                layer.add_line_segment(asset='grid',
-                                       from_here=Position(left_extent, h + self.Diagram.Origin.y),
-                                       to_there=Position(right_extent, h + self.Diagram.Origin.y)
-                                       )
+            for r, h in enumerate(self.Row_boundaries):
+                grid_layer.add_line_segment(asset='row boundary',
+                                            from_here=Position(left_extent, h + self.Diagram.Origin.y),
+                                            to_there=Position(right_extent, h + self.Diagram.Origin.y)
+                                            )
+                grid_layer.add_text_line(asset='grid label',
+                                         lower_left=Position(left_extent-20,self.Diagram.Origin.y+h+30),
+                                         text=str(r+1))
 
             # Draw columns
             bottom_extent = self.Diagram.Origin.y
             top_extent = bottom_extent + self.Diagram.Size.height
-            for w in self.Col_boundaries:
-                layer.add_line_segment(asset='grid',
-                                       from_here=Position(w + self.Diagram.Origin.x, bottom_extent),
-                                       to_there=Position(w + self.Diagram.Origin.x, top_extent)
-                                       )
+            for c, w in enumerate(self.Col_boundaries):
+                grid_layer.add_line_segment(asset='column boundary',
+                                            from_here=Position(w + self.Diagram.Origin.x, bottom_extent),
+                                            to_there=Position(w + self.Diagram.Origin.x, top_extent)
+                                            )
+                grid_layer.add_text_line(asset='grid label',
+                                         lower_left=Position(w+self.Diagram.Origin.x+30, bottom_extent-20),
+                                         text=str(c+1))
+
+            # Draw diagram boundary
+            grid_layer.add_rectangle(asset='grid boundary',
+                                     lower_left=Position(x=self.Diagram.Origin.x, y=self.Diagram.Origin.y),
+                                     size=self.Diagram.Size)
 
         # Draw nodes
         [n.render() for n in self.Nodes]
@@ -126,6 +137,7 @@ class Grid:
         # Draw connectors
         [c.render() for c in self.Connectors]
 
+
     def add_row(self, cell_height):
         """Adds an empty row upward with the given height"""
         # Compute the new y position relative to the Diagram y origin
