@@ -27,13 +27,15 @@ BranchLeaves = namedtuple('BranchLeaves', 'leaf_stems local_graft next_graft flo
 
 class XumlClassDiagram:
 
-    def __init__(self, xuml_model_path: Path, flatland_layout_path: Path, diagram_file_path: Path, rebuild=False):
+    def __init__(self, xuml_model_path: Path, flatland_layout_path: Path, diagram_file_path: Path,
+                 rebuild: bool, show_grid: bool):
         """Constructor"""
         self.logger = logging.getLogger(__name__)
         self.xuml_model_path = xuml_model_path
         self.flatland_layout_path = flatland_layout_path
         self.diagram_file_path = diagram_file_path
         self.rebuild = rebuild
+        self.show_grid = show_grid
 
         self.logger.info("Parsing the model")
         # Parse the model
@@ -103,6 +105,7 @@ class XumlClassDiagram:
             orientation=lspec.orientation,
             diagram_padding=padding,
             drawoutput=self.diagram_file_path,
+            show_grid=self.show_grid,
         )
 
     def draw_classes(self) -> Dict[str, SingleCellNode]:
